# -*- coding: utf-8 -*-

from trac.core import *
import re
from trac.env import IEnvironmentSetupParticipant
from trac.ticket.api import ITicketActionController, TicketSystem
from trac.ticket.default_workflow import ConfigurableTicketWorkflow
import trac.ticket.notification as note


class FlexibleReporterNotification(Component):
    """ FlexibleReporterNotification plugin """
    implements(IEnvironmentSetupParticipant)
    def __init__(self):

      old_get_recipients = note.TicketNotifyEmail.get_recipients

      def new_get_recipients(self, tktid):
        locally_enabled = self.env.compmgr.enabled.get(FlexibleReporterNotification)
        (torecipients, ccrecipients) = old_get_recipients(self,tktid)
        if not locally_enabled:
          self.env.log.debug('FlexibleReporterNotification: disabled, returning original results')
          return (torecipients, ccrecipients)

        self.env.log.debug('FlexibleReporterNotification: START tkt:%s, tos = %s, ccs = %s' % (tktid, torecipients, ccrecipients))

        #notify_reporter = self.config.getbool('notification', 'always_notify_reporter')
        for_reporting = self.config.getlist('notification','reporter_states')

        db = self.env.get_read_db()
        cursor = db.cursor()
        reporter = None

        # get email address
        cursor.execute("SELECT reporter FROM ticket WHERE id=%s", (tktid,))
        row = cursor.fetchone()
        if row:
            reporter = row[0]
            # self.env.log.debug('FlexibleReporterNotification: status %s' % self.ticket.values.get('status'))
            for S in for_reporting:
              if self.ticket.values.get('status') == S:
                 reporter = None


        def finder(r):
          if not r:
            return None
          rtn = (reporter == r)
          if rtn:
            self.env.log.debug('FlexibleReporterNotification: blocking recipient %s' % r)
            return rtn

        torecipients = [r for r in torecipients if not finder(r)]

        return (torecipients, ccrecipients)


      if self.compmgr.enabled[self.__class__]:
        note.TicketNotifyEmail.get_recipients = new_get_recipients

    def environment_created(self):
      pass

    def environment_needs_upgrade(self, db):
      pass

    def upgrade_environment(self, db):
      pass

